Package: MouseThymusAgeing
Type: Package
Title: Single-cell Transcriptomics Data of the Ageing Mouse Thymus
Version: 1.18.0
Authors@R: c(
    person("Mike", "Morgan", email="michael.morgan@abdn.ac.uk", role=c("aut", "cre")),
    person("Jeanette", "Baran-Gale", email="Jeanette.Baran-Gale@igmm.ed.ac.uk", role="aut"))
Description: 
    This package provides data access to counts matrices and meta-data for single-cell RNA sequencing data of 
    thymic epithlial cells across mouse ageing using SMARTseq2 and 10X Genommics chemistries. Access is provided 
    as a data package via ExperimentHub. It is designed to facilitate the re-use of data from Baran-Gale _et al._ 
    in a consistent format that includes relevant and informative meta-data. 
License: GPL-3
Encoding: UTF-8
biocViews: ExperimentHub, SingleCellData, ExpressionData,
        ExperimentData
Depends: SingleCellExperiment, SummarizedExperiment
Imports: ExperimentHub, methods, BiocGenerics, S4Vectors
Suggests: knitr, scuttle, rmarkdown, BiocStyle
VignetteBuilder: knitr
NeedsCompilation: no
Collate: 'getProcOrRaw.R' 'DropletMetadata.R' 'SMARTseqMetadata.R'
        'MouseDropletData.R' 'MouseSMARTseqData.R'
BugReports: https://github.com/MarioniLab/MouseThymusAgeing/issues
RoxygenNote: 7.1.1.9000
git_url: https://git.bioconductor.org/packages/MouseThymusAgeing
git_branch: RELEASE_3_22
git_last_commit: ad40f16
git_last_commit_date: 2025-10-29
Repository: Bioconductor 3.22
Date/Publication: 2025-11-04
Packaged: 2025-11-04 16:32:50 UTC; biocbuild
Author: Mike Morgan [aut, cre],
  Jeanette Baran-Gale [aut]
Maintainer: Mike Morgan <michael.morgan@abdn.ac.uk>
