# Generated by roxygen2: do not edit by hand

export(DropletMetadata)
export(MouseDropletData)
export(MouseSMARTseqData)
export(SMARTseqMetadata)
importClassesFrom(S4Vectors,DataFrame)
importFrom(BiocGenerics,"sizeFactors<-")
importFrom(BiocGenerics,sizeFactors)
importFrom(ExperimentHub,ExperimentHub)
importFrom(S4Vectors,List)
importFrom(SingleCellExperiment,SingleCellExperiment)
importFrom(SummarizedExperiment,colData)
importFrom(SummarizedExperiment,rowData)
importFrom(methods,as)
